@@ -1,6 +1,5 @@
 import contextlib
 import io
-import os
 import sys
 import termios
 import tty
@@ -158,7 +157,17 @@ def _attached_input(
     fd = input.fileno()
     previous = _current_callbacks.get((loop, fd))
 
-    loop.add_reader(fd, callback)
+    def callback_wrapper() -> None:
+        """Wrapper around the callback that already removes the reader when
+        the input is closed. Otherwise, we keep continuously calling this
+        callback, until we leave the context manager (which can happen a bit
+        later). This fixes issues when piping /dev/null into a prompt_toolkit
+        application."""
+        if input.closed:
+            loop.remove_reader(fd)
+        callback()
+
+    loop.add_reader(fd, callback_wrapper)
     _current_callbacks[loop, fd] = callback
 
     try:
@@ -243,9 +252,6 @@ class raw_mode:
 
             termios.tcsetattr(self.fileno, termios.TCSANOW, newattr)
 
-            # Put the terminal in cursor mode. (Instead of application mode.)
-            os.write(self.fileno, b"\x1b[?1l")
-
     @classmethod
     def _patch_lflag(cls, attrs):
         return attrs & ~(termios.ECHO | termios.ICANON | termios.IEXTEN | termios.ISIG)
